import { getAllRoleList } from '@/api/system/role/role';
import { BasicColumn, FormSchema } from '@/components/Table';
import { h } from 'vue';
import { Switch } from 'ant-design-vue';
import { useMessage } from '@/hooks/web/useMessage';
import { changeFlagApi } from '@/api/system/user/user';
// 引入开关组件
type CheckedType = boolean | string | number;

/** 列表筛选项*/
export const searchFormSchema: FormSchema[] = [
  {
    field: 'name',
    label: '',
    component: 'Input',
    colProps: { span: 4 },
    componentProps: {
      placeholder: '搜索算法',
    },
  },
  {
    field: 'flag',
    label: ' ',
    component: 'Select',
    colProps: { span: 4 },
    componentProps: {
      placeholder: '来源',
      options: [
        { label: '预置', value: '预置' },
        { label: '自定义', value: '自定义' },
      ],
    },
  },
];

/** 列表展示字段*/
export const columns: BasicColumn[] = [
  {
    title: '名称',
    dataIndex: 'name',
    width: 120,
  },
  {
    title: '函数名',
    dataIndex: 'functionName',
    width: 120,
  },
  {
    title: '算法描述',
    dataIndex: 'algorithmDes',
    width: 120,
  },
  {
    title: '来源',
    dataIndex: 'source',
    width: 140,
  },
  {
    title: '拥有者',
    dataIndex: 'owner',
    width: 140,
  },
  {
    title: '创建时间',
    dataIndex: 'createDate',
    width: 180,
  },
  {
    title: '更新时间',
    dataIndex: 'updateDate',
    width: 180,
  },
];

/** 新增编辑表单字段*/
export const formSchema: any[] = [
  {
    field: 'name',
    label: '名称',
    component: 'Input',
    rules: [
      {
        required: true,
        message: '请输入名称',
      },
    ],
  },
  {
    field: 'functionName',
    label: '函数名',
    component: 'Input',
    rules: [
      {
        required: true,
        message: '请输入函数名',
      },
    ],
  },
  {
    field: 'algorithmDes',
    label: '算法描述',
    component: 'Input',

  },
  {
    field: 'params',
    label: '参数',
    component: 'Select',
    componentProps: {
      options: [
        { label: 'STRING', value: 'STRING' },
        { label: 'INT', value: 'INT' },
      ],
    },

  },
  {
    field: 'describe',
    component: 'InputTextArea',
    label: '参数描述',
    componentProps: {
      placeholder: '请输入参数描述',
      rows: 1,
    },
  },
  {
    field: 'achieveMethod',
    component: 'Checkbox',
    label: '实现方式',
    colProps: {
      span: 8,
    },
    renderComponentContent: 'API',
  },

]
